%global upstreamver 0_8_1
%global pkgname polymaking

Name:           gap-pkg-%{pkgname}
Version:        %(tr _ . <<< %upstreamver)
Release:        11%{?dist}
Summary:        GAP interface to polymake

License:        GPLv2+
URL:            http://csserver.evansville.edu/~mroeder/polymaking.html
Source0:        http://csserver.evansville.edu/~mroeder/%{pkgname}/%{pkgname}%{upstreamver}.tar.bz2
# Remove unexpected trailing output from polymake (gmp version)
Patch0:         %{name}-output.patch
# Use a more modern test method
Patch1:         %{name}-test.patch
# This package relies on the old DIMS property, which has been removed from
# recent versions of polymake.  Instead, use the new INVERSE_RANK_MAP property.
# Consumers of the polymaking package will also have to be adjusted.
Patch2:         %{name}-dims.patch

BuildArch:      noarch

BuildRequires:  gap-devel
BuildRequires:  GAPDoc-latex
BuildRequires:  polymake

Requires:       gap-core
Requires:       polymake

%description
This package provides a very basic GAP interface to polymake.

%package doc
Summary:        Polymaking documentation
Requires:       %{name} = %{version}-%{release}
Requires:       gap-online-help

%description doc
This package contains documentation for gap-pkg-%{pkgname}.

%prep
%autosetup -p0 -n %{pkgname}

# Remove OS X files
find . -name .DS_Store | xargs rm -f

# Fix encoding
iconv -f iso8859-1 -t utf-8 PackageInfo.g > PackageInfo.g.utf8
touch -r PackageInfo.g PackageInfo.g.utf8
mv -f PackageInfo.g.utf8 PackageInfo.g

# Fix documentation markup
sed -i 's/\[: \(\[.*\]\)\]/\1/' doc/output.xml

# Fix an undefined LaTeX command in the BibTeX file
sed -i 's/URL/url/' doc/polymaking.bib

# Fix a reference to the main GAP manual
sed -i 's/The \.gaprc file/The gaprc file/' doc/environment.xml

%build
# Link to main GAP documentation
ln -s %{_gap_dir}/doc ../../doc
mkdir ../pkg
ln -s ../%{pkgname} ../pkg
echo %{version} > ../version.ver
gap -l "$PWD/..;%{_gap_dir}" << EOF
MakeGAPDocDoc( "doc", "polymaking", [], "polymaking", "../../..", "MathJax" );
CopyHTMLStyleFiles( "doc" );
GAPDocManualLab( "polymaking" );
EOF
rm -fr ../../doc ../{pkg,version.ver}

%install
mkdir -p %{buildroot}%{_gap_dir}/pkg
cp -a ../%{pkgname} %{buildroot}%{_gap_dir}/pkg
rm -f %{buildroot}%{_gap_dir}/pkg/%{pkgname}/{CHANGES,README}.polymaking
rm -f %{buildroot}%{_gap_dir}/pkg/%{pkgname}/LICENSE.txt
rm -f %{buildroot}%{_gap_dir}/pkg/%{pkgname}/doc/*.{aux,bbl,blg,brf,idx,ilg,ind,log,out,pnr,tex}

%check
# Produce less chatter while running the test
polymake --reconfigure - <<< exit;

# Now we can run the actual test.
gap -l "%{buildroot}%{_gap_dir};%{_gap_dir}" tst/testall.g

%files
%doc CHANGES.polymaking README.polymaking
%license LICENSE.txt
%{_gap_dir}/pkg/%{pkgname}/
%exclude %{_gap_dir}/pkg/%{pkgname}/doc/

%files doc
%docdir %{_gap_dir}/pkg/%{pkgname}/doc/
%{_gap_dir}/pkg/%{pkgname}/doc/

%changelog
* Fri Feb  1 2019 Jerry James <loganjerry@gmail.com> - 0.8.1-11
- Rebuild for gap 4.10.0
- Add a -doc subpackage
- Add the -test patch to use a more modern test method
- Add the -dims patch to adapt to recent versions of polymake

* Thu Jan 31 2019 Fedora Release Engineering <releng@fedoraproject.org> - 0.8.1-10
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Fri Jul 13 2018 Fedora Release Engineering <releng@fedoraproject.org> - 0.8.1-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Wed Feb 07 2018 Fedora Release Engineering <releng@fedoraproject.org> - 0.8.1-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Wed Jul 26 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0.8.1-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Fri Feb 10 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0.8.1-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Thu Apr  7 2016 Jerry James <loganjerry@gmail.com> - 0.8.1-5
- Rebuild for gap 4.8.3

* Wed Feb 03 2016 Fedora Release Engineering <releng@fedoraproject.org> - 0.8.1-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Wed Nov 11 2015 Jerry James <loganjerry@gmail.com> - 0.8.1-3
- Drop scriptlets; gap-core now uses rpm file triggers
- Rebuild documentation from source
- Add -output patch to fix misparsed polymake output

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.8.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Tue Jan 20 2015 Jerry James <loganjerry@gmail.com> - 0.8.1-1
- Initial RPM
